/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005-2006 EBM WebSourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: ComponentContextLocator.java,v 1.1 2007/06/11 13:34:07 lam Exp $
 * -------------------------------------------------------------------------
 */


package org.objectweb.petals.tools.rmi.client;

import java.net.MalformedURLException;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;

import org.objectweb.petals.tools.rmi.server.remote.interfaces.RemoteComponentContext;


/**
 * Get an instance of RMI Component context.
 * @author nsalatge
 *
 */
public final class ComponentContextLocator {

    /**
     * The registry itself.
     */
    private static java.rmi.registry.Registry registry;

    /**
     * the rmi component context.
     */
    private RemoteComponentContext rmiCc = null;

    /**
     * the default constructor.
     * @param rmiHost
     *         the ip address of the rmi host (if null, the localhost is contacted)
     * @param rmiPort
     *         the rmi port
     * @param rmiComponentContextName
     *         the rmi component context name
     * @throws MalformedURLException
     *           impossible to realized a remote access
     * @throws RemoteException
     *           impossible to realized a remote access
     * @throws NotBoundException
     *           impossible to realized a remote access
     */
    public ComponentContextLocator(final String rmiHost, final int rmiPort,
            final String rmiComponentContextName)
    throws MalformedURLException, RemoteException, NotBoundException {

        ComponentContextLocator.registry = java.rmi.registry.
        LocateRegistry.getRegistry(rmiHost, rmiPort);

        this.rmiCc = (RemoteComponentContext) ComponentContextLocator.registry.
        lookup(rmiComponentContextName);
    }

    /**
     *  Get an instance of RMI Component context.
     * @return
     *      the instance of RMI Component context.
     */
    public RemoteComponentContext getComponentContext() {
        return this.rmiCc;
    }

}
